==> analytics-2.4.1701.3-sources.jar: com/zing/zalo/zalosdk/analytics/internal/f.java <==
package com.zing.zalo.zalosdk.analytics.internal;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Application;
import android.content.ComponentName;
import android.content.Intent;
import android.net.Uri;
import com.zing.zalo.devicetrackingsdk.ZingAnalyticsManager;
import com.zing.zalo.zalosdk.analytics.internal.h.a;
import com.zing.zalo.zalosdk.core.log.Log;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Map;

public class f {
    public static f a = new f();
    public static Map<String, String> d = null;
    Application b;
    h c;
    private boolean e;
    private WeakReference<Activity> f;

    public f a(Application application) {
        this.b = application;
        return this;
    }

    @SuppressLint({"NewApi"})
    public void a() {
        if (this.b == null) {
            b();
            return;
        }
        this.c = h.b(this.b);
        this.c.a(new a(this) {
            final /* synthetic */ f a;

            {
                this.a = r1;
            }

            public void a(WeakReference<Activity> weakReference) {
                try {
                    this.a.e = true;
                    this.a.f = weakReference;
                    f.d.put("preloadDefault", ZingAnalyticsManager.getInstance().getPreloadChannelFromConfig());
                    ZingAnalyticsManager.getInstance().addEvent("open_app", f.d);
                    Activity activity = (Activity) weakReference.get();
                    if (activity != null) {
                        Intent intent = activity.getIntent();
                        Uri data = intent.getData();
                        ComponentName callingActivity = activity.getCallingActivity();
                        Map hashMap = new HashMap();
                        if (intent.hasCategory("android.intent.category.BROWSABLE") && data != null) {
                            hashMap.put("source", "com.google.android.browser");
                            hashMap.put("url", data.toString());
                        } else if (callingActivity != null) {
                            hashMap.put("source", callingActivity.getPackageName());
                            hashMap.put("url", callingActivity.getClassName());
                        }
                        if (hashMap.size() > 0) {
                            ZingAnalyticsManager.getInstance().addEvent("deep_linking", hashMap);
                        }
                    }
                } catch (Exception e) {
                    Log.e(e);
                }
            }

            public void b(WeakReference<Activity> weakReference) {
                this.a.e = false;
            }

            public void c(WeakReference<Activity> weakReference) {
                this.a.e = true;
                this.a.f = weakReference;
            }
        });
    }

    public void b() {
    }
}

==> analytics-2.4.1801-sources.jar: com/zing/zalo/zalosdk/analytics/internal/f.java <==
package com.zing.zalo.zalosdk.analytics.internal;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Application;
import android.content.ComponentName;
import android.content.Intent;
import android.net.Uri;
import com.zing.zalo.devicetrackingsdk.ZingAnalyticsManager;
import com.zing.zalo.zalosdk.analytics.internal.h.a;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.log.Log;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Map;

public class f {
    public static f a = new f();
    public static Map<String, String> d = null;
    Application b;
    h c;
    private boolean e;
    private WeakReference<Activity> f;

    public f a(Application application) {
        this.b = application;
        return this;
    }

    public WeakReference<Activity> a() {
        return this.f;
    }

    @SuppressLint({"NewApi"})
    public void b() {
        if (this.b == null) {
            c();
            return;
        }
        this.c = h.b(this.b);
        this.c.a(new a(this) {
            final /* synthetic */ f a;

            {
                this.a = r1;
            }

            public void a(WeakReference<Activity> weakReference) {
                try {
                    this.a.e = true;
                    this.a.f = weakReference;
                    f.d.put("preloadDefault", ZingAnalyticsManager.getInstance().getPreloadChannelFromConfig());
                    if (!(this.a.a() == null || this.a.a().get() == null)) {
                        f.d.put("wakeupInfo", Utils.loadListDeviceIDWakeUp(((Activity) this.a.a().get()).getApplicationContext()).toString());
                    }
                    ZingAnalyticsManager.getInstance().addEvent("open_app", f.d);
                    Activity activity = (Activity) weakReference.get();
                    if (activity != null) {
                        Intent intent = activity.getIntent();
                        Uri data = intent.getData();
                        ComponentName callingActivity = activity.getCallingActivity();
                        Map hashMap = new HashMap();
                        if (intent.hasCategory("android.intent.category.BROWSABLE") && data != null) {
                            hashMap.put("source", "com.google.android.browser");
                            hashMap.put("url", data.toString());
                        } else if (callingActivity != null) {
                            hashMap.put("source", callingActivity.getPackageName());
                            hashMap.put("url", callingActivity.getClassName());
                        }
                        if (hashMap.size() > 0) {
                            ZingAnalyticsManager.getInstance().addEvent("deep_linking", hashMap);
                        }
                    }
                } catch (Exception e) {
                    Log.e(e);
                }
            }

            public void b(WeakReference<Activity> weakReference) {
                this.a.e = false;
            }

            public void c(WeakReference<Activity> weakReference) {
                this.a.e = true;
                this.a.f = weakReference;
            }
        });
    }

    public void c() {
    }
}
